Skein
=====

|travis| |conda| |pypi|

Skein is a simple tool and library for deploying applications on `Apache YARN
<https://hadoop.apache.org/docs/current/hadoop-yarn/hadoop-yarn-site/YARN.html>`_.
See `the documentation <https://jcrist.github.io/skein/>`_ for more
information.

LICENSE
-------

New BSD. See the
`License File <https://github.com/jcrist/skein/blob/master/LICENSE>`_.

.. |travis| image:: https://travis-ci.org/jcrist/skein.svg?branch=master
   :target: https://travis-ci.org/jcrist/skein
.. |pypi| image:: https://img.shields.io/pypi/v/skein.svg
   :target: https://pypi.org/project/skein/
.. |conda| image:: https://img.shields.io/conda/vn/conda-forge/skein.svg
   :target: https://anaconda.org/conda-forge/skein
